==> Tickit-Widget-Tabbed-0.007.tar.gz: Tickit-Widget-Tabbed-0.007/examples/demo-custom-ribbon.pl <==
#!/usr/bin/perl

use strict;
use warnings;

use Tickit;

use Tickit::Widget::Static;
use Tickit::Widget::Tabbed;

my $tabbed = Tickit::Widget::Tabbed->new(
   tab_position => "bottom",
   ribbon_class => "CustomRibbon",
);
$tabbed->pen_active->chattrs( { b => 1, u => 1 } );

my $counter = 1;
sub add_tab
{
        $tabbed->add_tab(
                Tickit::Widget::Static->new( text => "Content for tab $counter" ),
                label => "tab$counter",
        );
        $counter++
}

add_tab for 1 .. 3;

my $tickit = Tickit->new();

$tickit->set_root_widget( $tabbed );

$tickit->bind_key(
        'C-a' => \&add_tab
);
$tickit->bind_key(
        'C-d' => sub {
                $tabbed->remove_tab( $tabbed->active_tab );
        },
);

$tickit->run;

package CustomRibbon;
use base qw( Tickit::Widget::Tabbed::Ribbon );

package CustomRibbon::horizontal;
use base qw( CustomRibbon );

use Tickit::Utils qw( textwidth );

sub lines { 1 }
sub cols  { 1 }

sub render
{
        my $self = shift;
        my %args = @_;

        my $win = $self->window or return;

        my @tabs = $self->tabs;

        my $col = 0;
        my $printed;

        # TODO: consider whether $win->print should return width?

        $win->goto( 0, $col );
        $win->print( $printed = sprintf "[%d tabs]: ", scalar @tabs );
        $col += textwidth $printed;

        my $active = $self->active_tab;
        $win->print( $printed = $active->label, $self->active_pen );
        $col += textwidth $printed;

        $win->print( $printed = " [also:" );
        $col += textwidth $printed;

        foreach my $tab ( @tabs ) {
                $win->erasech( 1, 1 ); $col += 1;
                if( $tab == $active ) {
                        $win->print( $printed = "x" x textwidth( $tab->label ), fg => 8 );
                }
                else {
                        $win->print( $printed = $tab->label );
                }
                $col += textwidth $printed;
        }

        $win->print( "]" );
        $col += 1;

        if( ( my $spare = $win->cols - $col ) > 0 ) {
                $win->erasech( $spare );
        }
}

sub scroll_to_visible { }

==> Tickit-Widget-Tabbed-0.016.tar.gz: Tickit-Widget-Tabbed-0.016/examples/demo-custom-ribbon.pl <==
#!/usr/bin/perl

use strict;
use warnings;

use Tickit;

use Tickit::Widget::Static;
use Tickit::Widget::Tabbed;

my $tabbed = Tickit::Widget::Tabbed->new(
   tab_position => "bottom",
   ribbon_class => "CustomRibbon",
   style => {
           active_b => 1,
           active_u => 1,
   },
);

my $counter = 1;
sub add_tab
{
        $tabbed->add_tab(
                Tickit::Widget::Static->new( text => "Content for tab $counter" ),
                label => "tab$counter",
        );
        $counter++
}

add_tab for 1 .. 3;

my $tickit = Tickit->new();

$tickit->set_root_widget( $tabbed );

$tickit->bind_key(
        'C-a' => \&add_tab
);
$tickit->bind_key(
        'C-d' => sub {
                $tabbed->remove_tab( $tabbed->active_tab );
        },
);

$tickit->run;

package CustomRibbon;
use base qw( Tickit::Widget::Tabbed::Ribbon );

use Tickit::Style -copy;

BEGIN {
        style_definition base =>
                current_fg => 8;
}

package CustomRibbon::horizontal;
use base qw( CustomRibbon );

use Tickit::Utils qw( textwidth );

sub lines { 1 }
sub cols  { 1 }

sub render_to_rb
{
        my $self = shift;
        my ( $rb, $rect ) = @_;

        my @tabs = $self->tabs;

        $rb->goto( 0, 0 );
        $rb->text( sprintf "[%d tabs]: ", scalar @tabs );

        my $active = $self->active_tab;
        $rb->text( $active->label, $self->active_pen );

        $rb->text( " [also:" );

        foreach my $tab ( @tabs ) {
                $rb->erase( 1 );
                if( $tab == $active ) {
                        $rb->text( "x" x textwidth( $tab->label ), $self->get_style_pen( "current" ) );
                }
                else {
                        $rb->text( $tab->label );
                }
        }

        $rb->text( "]" );

        $rb->erase_to( $self->window->cols );
}

sub scroll_to_visible { }
